__prog__     = "bsct"
__pkg_name__ = "django-bootstrap-crud-templates"
__author__   = "Z. Alem"
__licence__  = "GNU General Public License v3 (GPLv3)"
__version__  = "1.0.1"
__desc__     = "A repository of Bootstrap CRUD templates for Django."
