{% extends bsct_base|default:'base.html' %}

{% load bscttags %}

{% block BSCT_MAIN %}

    {% block BSCT_BOOTSTRAP_CDN %}
    {% bootstrap_cdn %}
    {% endblock %}

    {% block BSCT_CONTENT %}
    {% endblock %}

{% endblock %}
